pub enum LocalLocus {
Process,
Temp,
SandboxScope,
Worktree,
Adjacent,
WorktreeTrusted,
User,
Machine,
SystemIntegrity,
Device,
Kernel,
}Expand description
How deep into this host a capability reaches (v1.4 2.2). device/kernel
void the abstractions the fs rungs assume and are deny-by-default everywhere.
Variants
Process
Temp
SandboxScope
Worktree
Adjacent
WorktreeTrusted
User
Machine
SystemIntegrity
Device
Kernel