pub struct Profile {
pub capabilities: Vec<Capability>,
}Expand description
The set of capabilities a resolved command line exhibits (v1.4 2.8, 4.1). A profile passes a level iff every capability is admissible.
Fields
capabilities: Vec<Capability>Implementations